"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "io", {
    enumerable: true,
    get: function() {
        return io;
    }
});
const _workasyncstorageexternal = require("../app-render/work-async-storage.external");
const _workunitasyncstorageexternal = require("../app-render/work-unit-async-storage.external");
const _dynamicrendering = require("../app-render/dynamic-rendering");
const _invarianterror = require("../../shared/lib/invariant-error");
function io(expression, devAPICategory) {
    const workUnitStore = _workunitasyncstorageexternal.workUnitAsyncStorage.getStore();
    if (workUnitStore) {
        if (workUnitStore.type === 'prerender') {
            const workStore = _workasyncstorageexternal.workAsyncStorage.getStore();
            if (workStore) {
                (0, _dynamicrendering.abortOnSynchronousPlatformIOAccess)(workStore.route, expression, workUnitStore);
            }
        } else if (process.env.NODE_ENV === 'development' && workUnitStore.type === 'request' && workUnitStore.environment === 'Prerender') {
            const workStore = _workasyncstorageexternal.workAsyncStorage.getStore();
            const route = workStore ? workStore.route : '';
            switch(devAPICategory){
                case 'time':
                    {
                        const errorToLog = new Error(`Route "${route}" used ${expression} instead of using \`performance\` or without explicitly calling \`await connection()\` beforehand. See more info here: https://nextjs.org/docs/messages/next-prerender-current-time`);
                        console.error(errorToLog);
                        break;
                    }
                case 'random':
                    {
                        const errorToLog = new Error(`Route ${route} used ${expression} outside of \`"use cache"\` and without explicitly calling \`await connection()\` beforehand. See more info here: https://nextjs.org/docs/messages/next-prerender-random`);
                        console.error(errorToLog);
                        break;
                    }
                case 'crypto':
                    {
                        const errorToLog = new Error(`Route ${route} used ${expression} outside of \`"use cache"\` and without explicitly calling \`await connection()\` beforehand. See more info here: https://nextjs.org/docs/messages/next-prerender-crypto`);
                        console.error(errorToLog);
                        break;
                    }
                default:
                    throw new _invarianterror.InvariantError('Unknown devAPICategory in io function.');
            }
        }
    }
}

//# sourceMappingURL=utils.js.map